pub struct NetBenchTest { /* private fields */ }Expand description
A running benchmark.
Implementations
Sourceimpl NetBenchTest
impl NetBenchTest
Sourcepub async fn next(&mut self) -> Option<NetBenchEvent>
pub async fn next(&mut self) -> Option<NetBenchEvent>
Waits for the next progress event.
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Cancels the benchmark task without closing the caller-owned connection.
Call Self::abort_and_wait when the caller must prove that the internal task has exited.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Returns whether the internal benchmark task has finished.
Sourcepub async fn abort_and_wait(self) -> Result<()>
pub async fn abort_and_wait(self) -> Result<()>
Cancels the benchmark and waits until its internal task has exited.
Errors
Returns an error if the task panicked while cancellation was racing with completion.
Sourcepub async fn result(self) -> Result<NetBenchReport>
pub async fn result(self) -> Result<NetBenchReport>